@@ -17,6 +17,10 @@ class GitHelper:
     def commit_message() -> str:
         return git["log", -1, "--pretty=%B"]().strip()
 
+    @staticmethod
+    def commit_tag() -> str:
+        return git["tag", "--contains"]().strip()
+
     @staticmethod
     def remote_url():
         url = git['config', 'remote.origin.url']().strip()
@@ -28,5 +32,6 @@ class GitHelper:
 
 if __name__ == "__main__":
     print("Git hash:", GitHelper.commit_hash())
+    print("Git tag:", GitHelper.commit_tag())
     print("Git message:", GitHelper.commit_message())
     print("Git remote url:", GitHelper.remote_url())
